.terminal-container {
  background: #073642;
  min-height: 100vh;
}
.terminal-preview {
  width: 80px;
  height: 45px;
  background: #073642;
  display: block;
}
.terminal-preview img {
  max-width: 80px;
  max-height: 45px;
  display: block;
  margin: auto;
}
terminal {
  -moz-user-select: text;
  display: block;
  overflow: hidden;
  position: relative;
  margin: 25px;
}
terminal .paste-area {
  position: absolute;
  left: 0;
  top: 50%;
  bottom: 0;
  width: 100%;
  display: block;
  opacity: 0;
  font-size: 48px;
  text-align: center;
  border: 1px solid transparent;
  line-height: 100px;
}
terminal .paste-area:hover {
  opacity: .15;
}
terminal .paste-area.focus {
  opacity: .3;
  border: 1px solid white;
}
terminal .paste-area textarea {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  opacity: 0;
  cursor: pointer;
}
terminal .paste-area.focus textarea {
  cursor: text;
}

